@@ -313,9 +313,6 @@ def addResource(apiInstance, appInstance):
 def initialize(apiInstance, appInstance):
     log.success(initialize, 'ApiKeyManager is running')
 
-def afterHttpRequest(apiInstance, appInstance):
-    ...
-
 def onShutdown(apiInstance, appInstance):
     @appInstance.teardown_appcontext
     def closeApiKeyManager(error):
